@@ -24,79 +24,32 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-route53-alb`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.route53alb`|
 
-## Overview
-
 This AWS Solutions Construct implements an Amazon Route53 Hosted Zone routing to an Application Load Balancer
 
-Here is a minimal deployable pattern definition:
-
-Typescript
+Here is a minimal deployable pattern definition in Typescript:
 
 ```python
-import { Construct } from 'constructs';
-import { Stack, StackProps } from 'aws-cdk-lib';
 import { Route53ToAlb } from '@aws-solutions-constructs/aws-route53-alb';
 
-// Note - all alb constructs turn on ELB logging by default, so require that an environment including account
-// and region be provided when creating the stack
-//
-// new MyStack(app, 'id', {env: {account: '123456789012', region: 'us-east-1' }});
 new Route53ToAlb(this, 'Route53ToAlbPattern', {
   privateHostedZoneProps: {
     zoneName: 'www.example.com',
-  },
+  }
   publicApi: false,
 });
 ```
 
-Python
+## Initializer
 
-```python
-from aws_solutions_constructs.aws_route53_alb import Route53ToAlb
-from aws_cdk import (
-    aws_route53 as route53,
-    Stack
-)
-from constructs import Construct
-
-# Note - all alb constructs turn on ELB logging by default, so require that an environment including account
-# and region be provided when creating the stack
-#
-# MyStack(app, 'id', env=cdk.Environment(account='679431688440', region='us-east-1'))
-Route53ToAlb(self, 'Route53ToAlbPattern',
-                public_api=False,
-                private_hosted_zone_props=route53.HostedZoneProps(
-                    zone_name='www.example.com',
-                )
-                )
+```text
+new Route53ToAlb(scope: Construct, id: string, props: Route53ToAlbProps);
 ```
 
-Java
+*Parameters*
 
-```java
-import software.constructs.Construct;
-
-import software.amazon.awscdk.Stack;
-import software.amazon.awscdk.StackProps;
-import software.amazon.awscdk.services.route53.*;
-import software.amazon.awsconstructs.services.route53alb.*;
-
-// Note - all alb constructs turn on ELB logging by default, so require that an environment including account
-// and region be provided when creating the stack
-//
-// new MyStack(app, "id", StackProps.builder()
-//         .env(Environment.builder()
-//                 .account("123456789012")
-//                 .region("us-east-1")
-//                 .build());
-new Route53ToAlb(this, "Route53ToAlbPattern",
-        new Route53ToAlbProps.Builder()
-                .privateHostedZoneProps(new HostedZoneProps.Builder()
-                        .zoneName("www.example.com")
-                        .build())
-                .publicApi(false)
-                .build());
-```
+* scope [`Construct`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_core.Construct.html)
+* id `string`
+* props [`Route53ToAlbProps`](#pattern-construct-props)
 
 ## Pattern Construct Props
 
@@ -113,7 +66,7 @@ This construct can create Private Hosted Zones. If you want a Private Hosted Zon
 | vpcProps? | [ec2.VpcProps](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.VpcProps.html) | Optional custom properties for a VPC the construct will create. This VPC will be used by the new ALB and any Private Hosted Zone the construct creates (that's why loadBalancerProps and privateHostedZoneProps can't include a VPC). Providing both this and existingVpc is an error. |
 | existingVpc? | [ec2.IVpc](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-ec2.IVpc.html) | An existing VPC in which to deploy the construct. Providing both this and vpcProps is an error. If the client provides an existing load balancer and/or existing Private Hosted Zone, those constructs must exist in this VPC. |
 | logAlbAccessLogs? | boolean| Whether to turn on Access Logs for the Application Load Balancer. Uses an S3 bucket with associated storage costs.Enabling Access Logging is a best practice. default - true |
-| albLoggingBucketProps? | [s3.BucketProps](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html) | Optional properties to customize the bucket used to store the ALB Access Logs. Supplying this and setting logAlbAccessLogs to false is an error. @default - none |
+| albLoggingBucketProps? | [s3.BucketProps](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html) | Optional properties to customize the bucket used to store the ALB Access Logs. Supplying this and setting logAccessLogs to false is an error. @default - none |
 
 | publicApi | boolean | Whether the construct is deploying a private or public API. This has implications for the Hosted Zone, VPC and ALB. |
 
@@ -135,7 +88,7 @@ Out of the box implementation of the Construct without any override will set the
 
 ### Application Load Balancer
 
-* Creates an Application Load Balancer with no Listener or target. The construct can incorporate an existing, fully configured ALB if provided.
+* Creates an Application Load Balancer with no Listener or target. The consruct can incorporate an existing, fully configured ALB if provided.
 
 ## Architecture
 
@@ -144,7 +97,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -156,19 +109,17 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_ec2
 import aws_cdk.aws_elasticloadbalancingv2
 import aws_cdk.aws_route53
 import aws_cdk.aws_s3
-import aws_cdk.core
+import constructs
 
 
 class Route53ToAlb(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-route53-alb.Route53ToAlb",
 ):
@@ -178,18 +129,18 @@ class Route53ToAlb(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         public_api: builtins.bool,
-        alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        alb_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         existing_hosted_zone_interface: typing.Optional[aws_cdk.aws_route53.IHostedZone] = None,
         existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         load_balancer_props: typing.Any = None,
         log_alb_access_logs: typing.Optional[builtins.bool] = None,
         private_hosted_zone_props: typing.Any = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -207,25 +158,6 @@ class Route53ToAlb(
         :access: public
         :summary: Constructs a new instance of the Route53ToAlb class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                public_api: builtins.bool,
-                alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                existing_hosted_zone_interface: typing.Optional[aws_cdk.aws_route53.IHostedZone] = None,
-                existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                load_balancer_props: typing.Any = None,
-                log_alb_access_logs: typing.Optional[builtins.bool] = None,
-                private_hosted_zone_props: typing.Any = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = Route53ToAlbProps(
             public_api=public_api,
             alb_logging_bucket_props=alb_logging_bucket_props,
@@ -240,19 +172,19 @@ class Route53ToAlb(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="hostedZone")
     def hosted_zone(self) -> aws_cdk.aws_route53.IHostedZone:
         return typing.cast(aws_cdk.aws_route53.IHostedZone, jsii.get(self, "hostedZone"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="loadBalancer")
     def load_balancer(
         self,
     ) -> aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer:
         return typing.cast(aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer, jsii.get(self, "loadBalancer"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="vpc")
     def vpc(self) -> aws_cdk.aws_ec2.IVpc:
         return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
@@ -278,14 +210,14 @@ class Route53ToAlbProps:
         self,
         *,
         public_api: builtins.bool,
-        alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
+        alb_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         existing_hosted_zone_interface: typing.Optional[aws_cdk.aws_route53.IHostedZone] = None,
         existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         load_balancer_props: typing.Any = None,
         log_alb_access_logs: typing.Optional[builtins.bool] = None,
         private_hosted_zone_props: typing.Any = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
     ) -> None:
         '''
         :param public_api: Whether to create a public or private API. This value has implications for the VPC, the type of Hosted Zone and the Application Load Balancer Default: - None
@@ -302,30 +234,6 @@ class Route53ToAlbProps:
             alb_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**alb_logging_bucket_props)
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
-        if __debug__:
-            def stub(
-                *,
-                public_api: builtins.bool,
-                alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
-                existing_hosted_zone_interface: typing.Optional[aws_cdk.aws_route53.IHostedZone] = None,
-                existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                load_balancer_props: typing.Any = None,
-                log_alb_access_logs: typing.Optional[builtins.bool] = None,
-                private_hosted_zone_props: typing.Any = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
-            check_type(argname="argument alb_logging_bucket_props", value=alb_logging_bucket_props, expected_type=type_hints["alb_logging_bucket_props"])
-            check_type(argname="argument existing_hosted_zone_interface", value=existing_hosted_zone_interface, expected_type=type_hints["existing_hosted_zone_interface"])
-            check_type(argname="argument existing_load_balancer_obj", value=existing_load_balancer_obj, expected_type=type_hints["existing_load_balancer_obj"])
-            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
-            check_type(argname="argument load_balancer_props", value=load_balancer_props, expected_type=type_hints["load_balancer_props"])
-            check_type(argname="argument log_alb_access_logs", value=log_alb_access_logs, expected_type=type_hints["log_alb_access_logs"])
-            check_type(argname="argument private_hosted_zone_props", value=private_hosted_zone_props, expected_type=type_hints["private_hosted_zone_props"])
-            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "public_api": public_api,
         }
