@@ -8,22 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_elasticloadbalancingv2._jsii
-import aws_cdk.aws_route53._jsii
-import aws_cdk.aws_route53_targets._jsii
-import aws_cdk.aws_s3._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-route53-alb",
-    "1.181.0",
+    "2.2.0",
     __name__[0:-6],
-    "aws-route53-alb@1.181.0.jsii.tgz",
+    "aws-route53-alb@2.2.0.jsii.tgz",
 )
 
 __all__ = [
